﻿namespace IKVM.Test
{
    using System;
    using System.Diagnostics;
    using System.Collections.Generic;

    class Program
    {
        static void Main(string[] args)
        {
            Console.WriteLine("****************************************");
            Console.WriteLine("Using IKVM Statically:");
            Console.WriteLine("****************************************");
            IKVMParse();
            Console.WriteLine();
            Console.WriteLine("****************************************");
            Console.WriteLine("Using StringTemplate C# port:");
            Console.WriteLine("****************************************");
            STNETParse();

            Console.ReadKey();
        }
        public static void WriteTime(string title, long time)
        {
            Console.Write(title + ": ");
            long millisecondes = time % 1000;
            long minutes = time / 1000 / 60;
            long seconds = (time - minutes * 60 * 1000) / 1000;
            if (minutes > 0)
                Console.Write(minutes.ToString() + "m, ");
            if (seconds > 0)
                Console.Write(seconds.ToString() + "s, ");
            Console.WriteLine(millisecondes.ToString() + "ms");
        }
        private static void IKVMParse()
        {
            org.antlr.stringtemplate.StringTemplateGroup group = new org.antlr.stringtemplate.StringTemplateGroup("st-test"
                , ".\\st", typeof(org.antlr.stringtemplate.language.DefaultTemplateLexer));
            org.antlr.stringtemplate.StringTemplate st = group.lookupTemplate("contact_list_ikvm");
            // a simple attribute
            st.setAttribute("simple_attribute", "Hello StringTemplate!");
            // an object with properties as an attribute
            ContactJava c = new ContactJava("Richie", "Richie-test@gmail.com", 100);
            st.setAttribute("contact", c);
            // collections test for Map
            java.util.Map map = new java.util.HashMap();
            map.put("key1", 111);
            map.put("key2", 222);
            map.put("key3", 333);
            st.setAttribute("items_hashtable", map);
            // collections test for Array
            int[] array = new int[3];
            array[0] = 1999;
            array[1] = 2888;
            array[2] = 3777;
            st.setAttribute("items_array", array);
            // collections test for List
            java.util.List list = new java.util.ArrayList();
            list.add(new ContactJava("Jacky Pan", "JackyPan-test@gmail.com", 1608));
            list.add(new ContactJava("RicCC", "RicCC-test@gmail.com", 180));
            list.add(new ContactJava("Richie", "Richie-test@gmail.com", 682));
            st.setAttribute("items_list", list);
            Console.WriteLine(st.toString());
        }
        private static void STNETParse()
        {
            Antlr3.ST.StringTemplateGroup group = new Antlr3.ST.StringTemplateGroup("st-test", ".\\st");
            Antlr3.ST.StringTemplate st = group.LookupTemplate("contact_list_net");
            // a simple attribute
            st.SetAttribute("simple_attribute", "Hello StringTemplate!");
            // an object with properties as an attribute
            ContactNET c = new ContactNET() { Name = "Richie", EMail = "Richie-test@gmail.com", Score = 100 };
            st.SetAttribute("contact", c);
            // collections test for Map
            IDictionary<string, int> map = new Dictionary<string, int>();
            map.Add("key1", 111);
            map.Add("key2", 222);
            map.Add("key3", 333);
            st.SetAttribute("items_hashtable", map);
            // collections test for Array
            int[] array = new int[3];
            array[0] = 1999;
            array[1] = 2888;
            array[2] = 3777;
            st.SetAttribute("items_array", array);
            // collections test for List
            IList<ContactNET> list = new List<ContactNET>();
            list.Add(new ContactNET() { Name = "Jacky Pan", EMail = "JackyPan-test@gmail.com", Score = 1608 });
            list.Add(new ContactNET() { Name = "RicCC", EMail = "RicCC-test@gmail.com", Score = 180 });
            list.Add(new ContactNET() { Name = "Richie", EMail = "Richie-test@gmail.com", Score = 682 });
            st.SetAttribute("items_list", list);
            Console.WriteLine(st.ToString());
        }
    }
}